{-# LANGUAGE OverloadedStrings #-}

import Data.GI.CodeGen.CabalHooks (setupHaskellGIBinding)

main :: IO ()
main = setupHaskellGIBinding name version verbose overridesFile outputDir
  where name = "Dbusmenu"
        version = "0.4"
        overridesFile = Just "Dbusmenu.overrides"
        verbose = False
        outputDir = Nothing
